@@ -46,15 +46,15 @@ class Layout(Container):
     else:
       self.output.tag = 'div class="' + self.type + '"'
 
-  def __str__(self):
+  def __unicode__(self):
     return 'Layout of type ' + self.type
 
 class StandardLayout(Layout):
-  "A standard layout -- can be a true div or a span"
+  "A standard layout -- can be a true div or nothing at all"
 
   def process(self):
     self.type = 'standard'
-    self.output.tag = 'span class="Standard"'
+    self.output = ContentsOutput()
 
 class Title(Layout):
   "The title of the whole document"
@@ -62,8 +62,7 @@ class Title(Layout):
   def process(self):
     self.type = 'title'
     self.output.tag = 'h1 class="title"'
-    string = self.searchfor(StringContainer)
-    self.title = string.contents[0]
+    self.title = self.extracttext()
     Trace.message('Title: ' + self.title)
 
 class Author(Layout):
@@ -72,9 +71,10 @@ class Author(Layout):
   def process(self):
     self.type = 'author'
     self.output.tag = 'h2 class="author"'
-    string = self.searchfor(StringContainer)
-    FooterOutput.author = string.contents[0]
-    Trace.debug('Author: ' + FooterOutput.author)
+    strings = self.searchall(StringContainer)
+    if len(strings) > 0:
+      FooterOutput.author = strings[0].contents[0]
+      Trace.debug('Author: ' + FooterOutput.author)
 
 class Abstract(Layout):
   "A paper abstract"
@@ -162,3 +162,10 @@ class List(FirstWorder):
     tag = 'span class="List-entry"'
     self.contents.insert(0, TaggedText().complete(firstword, tag))
 
+class PlainLayout(Layout):
+  "A plain layout"
+
+  def process(self):
+    "Do nothing"
+    self.type = 'Plain'
+
