@@ -36,7 +36,7 @@ class Parser(object):
 
   def parseheader(self, reader):
     "Parse the header"
-    header = reader.currentsplit()
+    header = reader.currentline().split()
     reader.nextline()
     self.begin = reader.linenumber
     return header
@@ -86,6 +86,11 @@ class Parser(object):
       attrs[attrkey] = value
     return key, attrs
 
+  def parseending(self, reader, process):
+    "Parse until the current ending is found"
+    while not reader.currentline().startswith(self.ending):
+      process()
+
   def __unicode__(self):
     "Return a description"
     return self.__class__.__name__ + ' (' + unicode(self.begin) + ')'
@@ -120,7 +125,7 @@ class TextParser(Parser):
 
   def isending(self, reader):
     "Check if text is ending"
-    current = reader.currentsplit()
+    current = reader.currentline().split()
     if len(current) == 0:
       return False
     if current[0] in self.endings:
@@ -137,11 +142,13 @@ class ExcludingParser(Parser):
   def parse(self, reader):
     "Parse everything up to (and excluding) the final line"
     contents = []
-    while not reader.currentnonblank().startswith(self.ending):
-      containers = self.factory.createsome(reader)
-      contents += containers
+    self.parseending(reader, lambda: self.parsecontainers(reader, contents))
     return contents
 
+  def parsecontainers(self, reader, contents):
+    containers = self.factory.createsome(reader)
+    contents += containers
+
 class BoundedParser(ExcludingParser):
   "A parser bound by a final line"
 
@@ -157,8 +164,7 @@ class BoundedDummy(Parser):
 
   def parse(self, reader):
     "Parse the contents of the container"
-    while not reader.currentline().startswith(self.ending):
-      reader.nextline()
+    self.parseending(reader, lambda: reader.nextline())
     # skip last line
     reader.nextline()
     return []
@@ -183,7 +189,7 @@ class InsetParser(BoundedParser):
   def parse(self, reader):
     "Parse inset parameters into a dictionary"
     startcommand = ContainerConfig.string['startcommand']
-    while reader.currentline() != '\n' and not reader.currentline().startswith(startcommand):
+    while reader.currentline() != '' and not reader.currentline().startswith(startcommand):
       self.parseparameter(reader)
     return BoundedParser.parse(self, reader)
 
@@ -192,9 +198,7 @@ class HeaderParser(Parser):
 
   def parse(self, reader):
     "Parse header parameters into a dictionary"
-    while not reader.currentline().startswith(self.ending):
-      self.parseline(reader)
-      reader.nextline()
+    self.parseending(reader, lambda: self.parseline(reader))
     # skip last line
     reader.nextline()
     return []
